@@ -47,13 +47,20 @@ func TestWithDefaults(t *testing.T) {
 				Gomips: []string{
 					"softfloat",
 				},
+				Goamd64: []string{
+					"v2",
+					"v3",
+				},
 				GoBinary: "go1.2.3",
 			},
 			targets: []string{
-				"linux_amd64",
+				"linux_amd64_v2",
+				"linux_amd64_v3",
 				"linux_mips_softfloat",
-				"darwin_amd64",
-				"windows_amd64",
+				"darwin_amd64_v2",
+				"darwin_amd64_v3",
+				"windows_amd64_v3",
+				"windows_amd64_v2",
 				"windows_arm_6",
 				"linux_arm_6",
 			},
@@ -65,10 +72,10 @@ func TestWithDefaults(t *testing.T) {
 				Binary: "foo",
 			},
 			targets: []string{
-				"linux_amd64",
+				"linux_amd64_v1",
 				"linux_386",
 				"linux_arm64",
-				"darwin_amd64",
+				"darwin_amd64_v1",
 				"darwin_arm64",
 			},
 			goBinary: "go",
@@ -79,12 +86,12 @@ func TestWithDefaults(t *testing.T) {
 				Binary: "foo",
 				Targets: []string{
 					"linux_386",
-					"darwin_amd64",
+					"darwin_amd64_v2",
 				},
 			},
 			targets: []string{
 				"linux_386",
-				"darwin_amd64",
+				"darwin_amd64_v2",
 			},
 			goBinary: "go",
 		},
@@ -95,10 +102,10 @@ func TestWithDefaults(t *testing.T) {
 				Dir:    "./testdata",
 			},
 			targets: []string{
-				"linux_amd64",
+				"linux_amd64_v1",
 				"linux_386",
 				"linux_arm64",
-				"darwin_amd64",
+				"darwin_amd64_v1",
 				"darwin_arm64",
 			},
 			goBinary: "go",
@@ -110,10 +117,10 @@ func TestWithDefaults(t *testing.T) {
 				Dir:    "./nope",
 			},
 			targets: []string{
-				"linux_amd64",
+				"linux_amd64_v1",
 				"linux_386",
 				"linux_arm64",
-				"darwin_amd64",
+				"darwin_amd64_v1",
 				"darwin_arm64",
 			},
 			goBinary: "go",
@@ -194,6 +201,13 @@ func TestInvalidTargets(t *testing.T) {
 			},
 			expectedErr: "invalid gomips: mehfloat",
 		},
+		"goamd64": {
+			build: config.Build{
+				Goarch:  []string{"amd64"},
+				Goamd64: []string{"v1", "v431"},
+			},
+			expectedErr: "invalid goamd64: v431",
+		},
 	} {
 		t.Run(s, func(t *testing.T) {
 			config := config.Project{
