@@ -49,14 +49,14 @@ var fakeInfo = context.GitInfo{
 }
 
 func getInfo(ctx *context.Context) (context.GitInfo, error) {
-	if !git.IsRepo() && ctx.Snapshot {
+	if !git.IsRepo(ctx) && ctx.Snapshot {
 		log.Warn("accepting to run without a git repo because this is a snapshot")
 		return fakeInfo, nil
 	}
-	if !git.IsRepo() {
+	if !git.IsRepo(ctx) {
 		return context.GitInfo{}, ErrNotRepository
 	}
-	info, err := getGitInfo()
+	info, err := getGitInfo(ctx)
 	if err != nil && ctx.Snapshot {
 		log.WithError(err).Warn("ignoring errors because this is a snapshot")
 		if info.Commit == "" {
@@ -67,28 +67,28 @@ func getInfo(ctx *context.Context) (context.GitInfo, error) {
 	return info, err
 }
 
-func getGitInfo() (context.GitInfo, error) {
-	branch, err := getBranch()
+func getGitInfo(ctx *context.Context) (context.GitInfo, error) {
+	branch, err := getBranch(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get current branch: %w", err)
 	}
-	short, err := getShortCommit()
+	short, err := getShortCommit(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get current commit: %w", err)
 	}
-	full, err := getFullCommit()
+	full, err := getFullCommit(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get current commit: %w", err)
 	}
-	date, err := getCommitDate()
+	date, err := getCommitDate(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get commit date: %w", err)
 	}
-	summary, err := getSummary()
+	summary, err := getSummary(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get summary: %w", err)
 	}
-	gitURL, err := getURL()
+	gitURL, err := getURL(ctx)
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get remote URL: %w", err)
 	}
@@ -102,7 +102,7 @@ func getGitInfo() (context.GitInfo, error) {
 		gitURL = u.String()
 	}
 
-	tag, err := getTag()
+	tag, err := getTag(ctx)
 	if err != nil {
 		return context.GitInfo{
 			Branch:      branch,
@@ -116,22 +116,22 @@ func getGitInfo() (context.GitInfo, error) {
 		}, ErrNoTag
 	}
 
-	subject, err := getTagWithFormat(tag, "contents:subject")
+	subject, err := getTagWithFormat(ctx, tag, "contents:subject")
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get tag subject: %w", err)
 	}
 
-	contents, err := getTagWithFormat(tag, "contents")
+	contents, err := getTagWithFormat(ctx, tag, "contents")
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get tag contents: %w", err)
 	}
 
-	body, err := getTagWithFormat(tag, "contents:body")
+	body, err := getTagWithFormat(ctx, tag, "contents:body")
 	if err != nil {
 		return context.GitInfo{}, fmt.Errorf("couldn't get tag content body: %w", err)
 	}
 
-	previous, err := getPreviousTag(tag)
+	previous, err := getPreviousTag(ctx, tag)
 	if err != nil {
 		// shouldn't error, will only affect templates
 		log.Warnf("couldn't find any tags before %q", tag)
@@ -163,10 +163,10 @@ func validate(ctx *context.Context) error {
 	if _, err := os.Stat(".git/shallow"); err == nil {
 		log.Warn("running against a shallow clone - check your CI documentation at https://goreleaser.com/ci")
 	}
-	if err := CheckDirty(); err != nil {
+	if err := CheckDirty(ctx); err != nil {
 		return err
 	}
-	_, err := git.Clean(git.Run("describe", "--exact-match", "--tags", "--match", ctx.Git.CurrentTag))
+	_, err := git.Clean(git.Run(ctx, "describe", "--exact-match", "--tags", "--match", ctx.Git.CurrentTag))
 	if err != nil {
 		return ErrWrongRef{
 			commit: ctx.Git.Commit,
@@ -177,20 +177,20 @@ func validate(ctx *context.Context) error {
 }
 
 // CheckDirty returns an error if the current git repository is dirty.
-func CheckDirty() error {
-	out, err := git.Run("status", "--porcelain")
+func CheckDirty(ctx *context.Context) error {
+	out, err := git.Run(ctx, "status", "--porcelain")
 	if strings.TrimSpace(out) != "" || err != nil {
 		return ErrDirty{status: out}
 	}
 	return nil
 }
 
-func getBranch() (string, error) {
-	return git.Clean(git.Run("rev-parse", "--abbrev-ref", "HEAD", "--quiet"))
+func getBranch(ctx *context.Context) (string, error) {
+	return git.Clean(git.Run(ctx, "rev-parse", "--abbrev-ref", "HEAD", "--quiet"))
 }
 
-func getCommitDate() (time.Time, error) {
-	ct, err := git.Clean(git.Run("show", "--format='%ct'", "HEAD", "--quiet"))
+func getCommitDate(ctx *context.Context) (time.Time, error) {
+	ct, err := git.Clean(git.Run(ctx, "show", "--format='%ct'", "HEAD", "--quiet"))
 	if err != nil {
 		return time.Time{}, err
 	}
@@ -205,24 +205,24 @@ func getCommitDate() (time.Time, error) {
 	return t, nil
 }
 
-func getShortCommit() (string, error) {
-	return git.Clean(git.Run("show", "--format='%h'", "HEAD", "--quiet"))
+func getShortCommit(ctx *context.Context) (string, error) {
+	return git.Clean(git.Run(ctx, "show", "--format='%h'", "HEAD", "--quiet"))
 }
 
-func getFullCommit() (string, error) {
-	return git.Clean(git.Run("show", "--format='%H'", "HEAD", "--quiet"))
+func getFullCommit(ctx *context.Context) (string, error) {
+	return git.Clean(git.Run(ctx, "show", "--format='%H'", "HEAD", "--quiet"))
 }
 
-func getSummary() (string, error) {
-	return git.Clean(git.Run("describe", "--always", "--dirty", "--tags"))
+func getSummary(ctx *context.Context) (string, error) {
+	return git.Clean(git.Run(ctx, "describe", "--always", "--dirty", "--tags"))
 }
 
-func getTagWithFormat(tag, format string) (string, error) {
-	out, err := git.Run("tag", "-l", "--format='%("+format+")'", tag)
+func getTagWithFormat(ctx *context.Context, tag, format string) (string, error) {
+	out, err := git.Run(ctx, "tag", "-l", "--format='%("+format+")'", tag)
 	return strings.TrimSpace(strings.TrimSuffix(strings.ReplaceAll(out, "'", ""), "\n\n")), err
 }
 
-func getTag() (string, error) {
+func getTag(ctx *context.Context) (string, error) {
 	var tag string
 	var err error
 	for _, fn := range []func() (string, error){
@@ -230,10 +230,10 @@ func getTag() (string, error) {
 			return os.Getenv("GORELEASER_CURRENT_TAG"), nil
 		},
 		func() (string, error) {
-			return git.Clean(git.Run("tag", "--points-at", "HEAD", "--sort", "-version:refname"))
+			return git.Clean(git.Run(ctx, "tag", "--points-at", "HEAD", "--sort", "-version:refname"))
 		},
 		func() (string, error) {
-			return git.Clean(git.Run("describe", "--tags", "--abbrev=0"))
+			return git.Clean(git.Run(ctx, "describe", "--tags", "--abbrev=0"))
 		},
 	} {
 		tag, err = fn()
@@ -245,14 +245,14 @@ func getTag() (string, error) {
 	return tag, err
 }
 
-func getPreviousTag(current string) (string, error) {
+func getPreviousTag(ctx *context.Context, current string) (string, error) {
 	if tag := os.Getenv("GORELEASER_PREVIOUS_TAG"); tag != "" {
 		return tag, nil
 	}
 
-	return git.Clean(git.Run("describe", "--tags", "--abbrev=0", fmt.Sprintf("tags/%s^", current)))
+	return git.Clean(git.Run(ctx, "describe", "--tags", "--abbrev=0", fmt.Sprintf("tags/%s^", current)))
 }
 
-func getURL() (string, error) {
-	return git.Clean(git.Run("ls-remote", "--get-url"))
+func getURL(ctx *context.Context) (string, error) {
+	return git.Clean(git.Run(ctx, "ls-remote", "--get-url"))
 }
