@@ -15,6 +15,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/commitauthor"
+	"github.com/goreleaser/goreleaser/internal/deprecate"
 	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -35,6 +36,9 @@ func (Pipe) String() string                 { return "gofish fish food cookbook"
 func (Pipe) Skip(ctx *context.Context) bool { return len(ctx.Config.Rigs) == 0 }
 
 func (Pipe) Default(ctx *context.Context) error {
+	if len(ctx.Config.Rigs) > 0 {
+		deprecate.Notice(ctx, "rigs")
+	}
 	for i := range ctx.Config.Rigs {
 		goFish := &ctx.Config.Rigs[i]
 
@@ -84,7 +88,10 @@ func doRun(ctx *context.Context, goFish config.GoFish, cl client.Client) error {
 			artifact.ByGoos("windows"),
 		),
 		artifact.Or(
-			artifact.ByGoarch("amd64"),
+			artifact.And(
+				artifact.ByGoarch("amd64"),
+				artifact.ByGoamd64("v1"),
+			),
 			artifact.ByGoarch("arm64"),
 			artifact.ByGoarch("all"),
 			artifact.And(
