@@ -19,9 +19,9 @@ import (
 	"github.com/goreleaser/goreleaser/internal/commitauthor"
 	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
+	"github.com/goreleaser/goreleaser/internal/yaml"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
-	"gopkg.in/yaml.v2"
 )
 
 const (
@@ -50,6 +50,9 @@ func (Pipe) Default(ctx *context.Context) error {
 		if krew.Name == "" {
 			krew.Name = ctx.Config.ProjectName
 		}
+		if krew.Goamd64 == "" {
+			krew.Goamd64 = "v1"
+		}
 	}
 
 	return nil
@@ -92,7 +95,10 @@ func doRun(ctx *context.Context, krew config.Krew, cl client.Client) error {
 			artifact.ByGoos("windows"),
 		),
 		artifact.Or(
-			artifact.ByGoarch("amd64"),
+			artifact.And(
+				artifact.ByGoarch("amd64"),
+				artifact.ByGoamd64(krew.Goamd64),
+			),
 			artifact.ByGoarch("arm64"),
 			artifact.ByGoarch("all"),
 			artifact.And(
